#
# spec file for package cppunit
#
# Copyright (c) 2020 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define libname libcppunit-1_15-1
Name:           cppunit
Version:        1.15.1
Release:        1.18
Summary:        C++ Port of the JUnit Testing Framework
License:        LGPL-2.1-or-later
URL:            https://www.freedesktop.org/wiki/Software/cppunit
Source:         http://dev-www.libreoffice.org/src/%{name}-%{version}.tar.gz
Source1:        cppunit-devel.desktop
Source99:       baselibs.conf
BuildRequires:  doxygen
BuildRequires:  gcc-c++
BuildRequires:  graphviz
BuildRequires:  libtool
BuildRequires:  pkgconfig
BuildRequires:  update-desktop-files

%description
CppUnit is the C++ port of the famous JUnit framework for unit testing.
Test output is in XML for automatic testing and GUI based for
supervised tests.

%package -n %{libname}
Summary:        Cppunit library for writting C++ unittests

%description -n %{libname}
Cppunit library for writting C++ unittests in JUnit like fashion.

%package devel
Summary:        Include Files and Libraries for cppunit
Requires:       %{libname} = %{version}
Suggests:       devel-doc = %{version}
Provides:       libcppunit-devel = %{version}
Obsoletes:      libcppunit-devel < %{version}

%description devel
Cppunit library, headers, and all relevant additions for writting C++ unittests
in JUnit like fashion.

%package devel-doc
Summary:        Documentation for the cppunit API
Conflicts:      libcppunit-devel < 1.13.2
BuildArch:      noarch

%description devel-doc
This package contains documentation for the cppunit API.

%prep
%autosetup

%build
export CXXFLAGS="%{optflags}"
%configure \
    --docdir=%{_docdir}/%{name} \
    --disable-silent-rules \
    --disable-static \
    --enable-doxygen
%make_build

%install
%make_install
# remove la archive
find %{buildroot} -type f -name "*.la" -delete -print
# remove INSTALL* files from package docs
find %{buildroot}%{_docdir}/%{name}/ -type f -name "INSTALL*" -delete -print
# this got also installed to _defaultdocdir
rm -rf %{buildroot}%{_datadir}/cppunit/html/
find %{buildroot}%{_includedir} -type f | xargs chmod a-x
# install susehelp file
mkdir -p %{buildroot}%{_datadir}/susehelp/meta/Development/Libraries/
install %{SOURCE1} %{buildroot}%{_datadir}/susehelp/meta/Development/Libraries/
%suse_update_desktop_file %{buildroot}%{_datadir}/susehelp/meta/Development/Libraries/cppunit-devel.desktop

%check
%make_build check

%post -n %{libname} -p /sbin/ldconfig
%postun -n %{libname} -p /sbin/ldconfig

%files -n %{libname}
%license COPYING
%doc AUTHORS
%{_libdir}/libcppunit*.so.*
%{_datadir}/cppunit

%files devel
%doc NEWS README THANKS ChangeLog
%dir %{_docdir}/%{name}
%{_docdir}/%{name}/*
%{_bindir}/DllPlugInTester
%{_libdir}/libcppunit*.so
%{_libdir}/pkgconfig/cppunit.pc
%{_includedir}/*

%files devel-doc
%doc doc/html/*
%{_datadir}/susehelp

%changelog
* Mon Jul 13 2020 Matthias Eliasson <elimat@opensuse.org>
- Version update to 1.15.1
  Portability:
  * Fix Wdefaulted-function-deleted warning with clang
  * Remove old Visual Studio project files
- Changes in version 1.15.0
  * Report (un)signed character as intergers
  * add CPPUNIT_TEST_FIXTURE()
  * add message_to_string trait to allow custom string formatters
  Portability:
  * Fix build with gcc 9
  * Fix various compiler warnings
- Run spec-cleaner
  * remove rpm groups
- Drop patches fixed upstream:
  * gcc9-Wdeprecated-copy-1.patch
  * gcc9-Wdeprecated-copy-2.patch
* Mon Apr 29 2019 Martin Liška <mliska@suse.cz>
- Add gcc9-Wdeprecated-copy-1.patch and gcc9-Wdeprecated-copy-2.patch
  in order to fix boo#1121281.
* Wed Feb  7 2018 jengelh@inai.de
- Fix RPM group of shlib subpackage.
* Wed Feb  7 2018 tchvatal@suse.com
- Fix description bsc#1079783
* Sun Apr 16 2017 tchvatal@suse.com
- Version update to 1.14.0:
  * TestCaller supports any callable that can be put into
    std::function<void()>.
  * CPPUNIT_TEST_PARAMETERIZED executes a test for any value in
    an iteratable.
  * Added new Assertion macros: ASSERT_LESS, ASSERT_GREATER,
    ASSERT_LESSEQUAL, ASSERT_GREATEREQUAL
  * Remove QT test runner
* Thu Nov 14 2013 tchvatal@suse.com
- Avoid collisions with libcppunit.
* Wed Nov 13 2013 tchvatal@suse.com
- Fix the desktop file placement and help location within it.
* Tue Nov 12 2013 tchvatal@suse.com
- Fix baselibs.conf
- Run tests and split documentation in own devel-doc subpackage.
- Remove la file and do not build static lib.
* Mon Nov 11 2013 tbehrens@suse.com
- Version bump to 1.13.2
  * report dlopen errors now correctly
* Mon Dec 17 2012 tchvatal@suse.com
- Version bump to 1.13.1
  * remove unused patches that are incorporated in the build system
  * cleanup the spec file at least a bit
* Fri Nov 23 2012 joop.boonen@opensuse.org
- Fixed SLE build replaced make_install makro by
  make DESTDIR=\%%{buildroot} install
* Fri Apr 20 2012 joop.boonen@opensuse.org
- Build cppunit 1.12.1
- Passed  the spec file through spec-cleaner
* Thu Feb  9 2012 jengelh@medozas.de
- Simply regeneration of autotools scripts
* Sun Nov 13 2011 jengelh@medozas.de
- Remove redundant/unwanted tags/section (cf. specfile guidelines)
- Use %%_smp_mflags for parallel building
- Add missing "make" call in %%build
* Sun Nov 13 2011 coolo@suse.com
- add libtool as explicit buildrequire to avoid implicit dependency from prjconf
* Fri Jun 19 2009 coolo@novell.com
- disable as-needed for this package as it fails to build with it
* Sun Jul 15 2007 aj@suse.de
- Use libcppunit-devel to follow lib package name scheme
* Wed Jul  4 2007 adrian@suse.de
- update to version 0.12.0
  - minor bugfixes
  - now generated with doxygen 1.4.7 new 'tabs' style.
- rename package to follow lib package name scheme
* Sun Apr 22 2007 dmueller@suse.de
- don't install devel files as executable
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Fri Aug 12 2005 dmueller@suse.de
- actually apply the quoting patch
* Tue Dec  7 2004 pth@suse.de
- Fix quoting in AC_DEFUN
* Tue Nov 16 2004 adrian@suse.de
- do not package debug dir
- translate suse help desktop file
* Thu Aug 12 2004 ro@suse.de
- added libpng to neededforbuild (for doxygen)
* Mon Jul 26 2004 adrian@suse.de
- remove unneeded /usr/bin/simple to solve conflicts
* Mon Jun 21 2004 adrian@suse.de
- update to version 1.10.2
- add susehelp desktop file
* Sat Mar 20 2004 adrian@suse.de
- remove executable permissions of header files (#36337)
* Tue Jul 29 2003 adrian@suse.de
- initial package of version 1.8.0
